@@ -17,11 +17,11 @@ this infomations for ban whith iptables.
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 our @ISA    = qw(Exporter);
 our @EXPORT = qw(tail initCount);
@@ -54,7 +54,8 @@ Perhaps a little code snippet.
 
 加入crontab 每5分钟执行一次。
 
-   echo "*/5 * * * * perl $dir/banip.pl >> bianip.logs 2>&1 " >> /var/spool/cron/ro
+   echo "*/5 * * * * perl $dir/banip.pl >> bianip.logs 2>&1 " >> /var/spool/cron/root
+
 =head1 SUBROUTINES/METHODS
 
 =cut
